@@ -52,7 +52,7 @@ from sphinx.writers.latex import LaTeXTranslator
 from sphinx_toolbox.cache import cache
 from sphinx_toolbox.utils import make_github_url
 
-__all__ = [
+__all__ = (
 		"IssueNode",
 		"IssueNodeWithName",
 		"issue_role",
@@ -60,7 +60,7 @@ __all__ = [
 		"visit_issue_node",
 		"depart_issue_node",
 		"get_issue_title",
-		]
+		)
 
 
 class IssueNode(nodes.reference):
@@ -89,7 +89,7 @@ class IssueNode(nodes.reference):
 		super().__init__(source, source, refuri=self.issue_url)
 
 	@property
-	def _copy_kwargs(self):  # pragma: no cover
+	def _copy_kwargs(self):  # pragma: no cover  # noqa: MAN002
 		return {"issue_number": self.issue_number, "refuri": self.issue_url}
 
 	def copy(self) -> "IssueNode":  # pragma: no cover
@@ -250,7 +250,7 @@ def pull_role(
 	return [refnode], messages
 
 
-def visit_issue_node(translator: HTMLTranslator, node: IssueNode):
+def visit_issue_node(translator: HTMLTranslator, node: IssueNode) -> None:
 	"""
 	Visit an :class:`~.IssueNode`.
 
@@ -271,7 +271,7 @@ def visit_issue_node(translator: HTMLTranslator, node: IssueNode):
 		warnings.warn(f"Issue/Pull Request #{node.issue_number} not found.")
 
 
-def depart_issue_node(translator: HTMLTranslator, node: IssueNode):
+def depart_issue_node(translator: HTMLTranslator, node: IssueNode) -> None:
 	"""
 	Depart an :class:`~.IssueNode`.
 
@@ -284,7 +284,7 @@ def depart_issue_node(translator: HTMLTranslator, node: IssueNode):
 		translator.body.append("</abbr>")
 
 
-def _visit_issue_node_latex(translator: LaTeXTranslator, node: IssueNode):
+def _visit_issue_node_latex(translator: LaTeXTranslator, node: IssueNode) -> None:
 	"""
 	Visit an :class:`~.IssueNode`.
 
@@ -299,7 +299,7 @@ def _visit_issue_node_latex(translator: LaTeXTranslator, node: IssueNode):
 	translator.visit_reference(node)
 
 
-def _depart_issue_node_latex(translator: LaTeXTranslator, node: IssueNode):
+def _depart_issue_node_latex(translator: LaTeXTranslator, node: IssueNode) -> None:
 	"""
 	Depart an :class:`~.IssueNode`.
 
