@@ -45,10 +45,10 @@ from sphinx.application import Sphinx
 from sphinx_toolbox.more_autosummary import PatchedAutoSummModuleDocumenter
 from sphinx_toolbox.utils import SphinxExtMetadata, flag, metadata_add_version
 
-__all__ = ["automodule_add_nodocstring", "no_docstring_process_docstring", "setup"]
+__all__ = ("automodule_add_nodocstring", "no_docstring_process_docstring", "setup")
 
 
-def automodule_add_nodocstring(app) -> None:
+def automodule_add_nodocstring(app: Sphinx) -> None:
 	"""
 	Add the ``:no-docstring:`` option to automodule directives.
 
@@ -65,14 +65,14 @@ def automodule_add_nodocstring(app) -> None:
 	app.connect("autodoc-process-docstring", no_docstring_process_docstring, priority=1000)
 
 
-def no_docstring_process_docstring(
+def no_docstring_process_docstring(  # noqa: MAN001
 		app: Sphinx,
 		what,
 		name: str,
 		obj,
 		options,
 		lines: List[str],
-		):
+		) -> None:
 	"""
 	Remove module docstrings if the ``:no-docstring:`` flag was set.
 
